import axios from "axios"
import { ElMessage } from 'element-plus'
import router from "../../router/index.ts"

const baseUrl = '/api';
const Service = axios.create({
    timeout: 8000,
    baseURL: baseUrl,
    headers: {
        "Content-type": "application/json;charset=utf-8",
        "Authorization": ""
    }
})
// 添加请求拦截器
Service.interceptors.request.use(function (config) {
    // 在发送请求之前做些什么
    if (config.headers.Authorization == null || config.headers.Authorization == "") {
        // config.headers.Authorization = 'manage:eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJ1c2VyX2lkIjozLCJ1c2VyX25hbWUiOiJ5YW5nIiwicm9sZSI6ImFkbWluIiwiaXNzIjoibGNfb2F1dGgiLCJleHAiOjE3MjkyMTQ1MjV9.eyNs2QV4-e6TBKCh2KfxarWEM0Cmaw9cYEz1EMQ8838'
    }
    return config;
}, function (error) {
    // 对请求错误做些什么
    return Promise.reject(error);
});

// 添加响应拦截器
Service.interceptors.response.use(function (response) {
    const data = response.data;
    if (data.code != undefined) {
        if (data.code != 200 && data.code != 201) {
            if (data.code == 401) {
                router.push('/')
                return data;
            }
            ElMessage.error(data.message || "服务器出错")
            return data
        }
    }
    return data
}, function (error) {
    if (error && error.response) {
        switch (error.response.status) {
            case 400:
                error.message = '错误请求';
                break;
            case 401:
                error.message = '未授权，请重新登录';
                break;
            case 403:
                error.message = '禁止访问';
                break;
            case 404:
                error.message = '请求的资源不存在';
                break;
            case 408:
                error.message = '请求超时';
                break;
            case 500:
                error.message = '服务器内部错误';
                break;
            case 501:
                error.message = '服务未实现';
                break;
            case 502:
                error.message = '网关错误';
                break;
            case 503:
                error.message = '服务不可用';
                break;
            case 504:
                error.message = '网关超时';
                break;
            case 505:
                error.message = 'HTTP版本不受支持';
                break;
            default:
                error.message = `连接错误${error.response.status}`;
        }
    } else {
        error.message = '连接到服务器失败';
    }
    ElMessage.error(error.message || "服务器出错")
    // console.error('HTTP Error:', error);
    // 超出 2xx 范围的状态码都会触发该函数。
    // 对响应错误做点什么
    return Promise.reject(error);
});



// get请求
export const get = async (config: any) => {
    let ret = await Service({ ...config, method: "get", params: config.data })
    return ret
}

// post请求
export const post = async (config: any) => {
    let ret = await Service({ ...config, method: "post", data: config.data })
    return ret
}


// put请求
export const put = async (config: any) => {
    let ret = await Service({ ...config, method: "put", data: config.data })
    return ret
}

// delete请求
export const del = async (config: any) => {
    let ret = await Service({ ...config, method: "delete" })
    return ret
}